import { reactive, ref } from 'vue'
import { message } from 'ant-design-vue';
import * as gitee from '@/service/gitee'

const getParentPath = path => {
  const paths = path.split('/')
  paths.pop()
  return paths.join('/')       
}

export default function useNote() {
  const fileArr = reactive([])
  const fileTree = reactive([])
  const note = ref()

  // 获取目录下所有问题件
  const getFiles = (user, path, repo = 'my-note') => {
    return gitee.getFiles(user, path, repo).then(res => {
      const files = (res || []).filter (x => x.path.indexOf('.gitignore') === -1)

      if (!path) {
        fileArr.splice(0)
        fileArr.push(...files)
        fileTree.push(...files)
      } else {
        const dir = fileArr.filter(x => x.type === 'dir' && x.path === path)[0]
        dir.children = files
        fileArr.push(...files)
      }
    })
  }

  const getNote = (user, path = '', repo = 'my-note') => {
    return gitee.getFile(user, path, repo).then(res => note.value = res)
  }

  const newNote = (user, path, repo = 'my-note') => {
    gitee.newFile(user, '又是一篇崭新的日记...', path, repo).then(() => {
      getFiles(user, getParentPath(path), repo)
    })
  }

  const updateNote = (content, user) => {
    const filePath = note.value.url.replace(BASE_URL, '')
    const fileInfo = { filePath, sha: note.value.sha, content }

    return gitee.updateFile(user, content, fileInfo).then(() => {
      message.success('保存成功');
      // 获取最新的数据, 目的是更新 sha 值
      gitee.getFile(user, filePath, 'my-note').then(res => note.value = res)
    })
  }

  const newFolder = (user, path, repo = 'my-note') => {
    gitee.newFolder(user, path, repo).then(() => {
      getFiles(user, getParentPath(path), repo)
    })
  }
  
  return {
    fileArr,
    fileTree,
    note,
    getFiles,
    newFolder,
    getNote,
    newNote,
    updateNote,
  }
}
